@@ -1,4 +1,4 @@
-# Copyright 2020 The tfaip authors. All Rights Reserved.
+# Copyright 2021 The tfaip authors. All Rights Reserved.
 #
 # This file is part of tfaip.
 #
@@ -21,15 +21,20 @@ import tempfile
 import os
 
 
+work_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), '..', 'tutorial', 'workdir'))
+
+
 class TestPredictScript(unittest.TestCase):
     def test_predict_tutorial(self):
         with tempfile.TemporaryDirectory() as d:
-            check_call(['tfaip-train', 'tutorial',
-                        '--trainer_params', 'samples_per_epoch=10', 'epochs=1', f'checkpoint_dir={d}',
-                        '--data_params', 'train_batch_size=2',
+            check_call(['tfaip-train', 'examples.tutorial.full',
+                        '--trainer.samples_per_epoch', '10',
+                        '--trainer.epochs', '1',
+                        '--trainer.output_dir', d,
+                        '--train.batch_size', '2',
+                        '--val.limit', '10',
                         ])
             check_call(['tfaip-predict',
-                        '--predict_lists', 'NONE',
+                        '--data.files', os.path.join(work_dir, 'data', '*.png'),
                         '--export_dir', os.path.join(d, 'best'),
-                        '--data_params', 'val_limit=10',
                         ])
