@@ -1,4 +1,4 @@
-# Copyright 2020 The tfaip authors. All Rights Reserved.
+# Copyright 2021 The tfaip authors. All Rights Reserved.
 #
 # This file is part of tfaip.
 #
@@ -16,10 +16,13 @@
 # tfaip. If not, see http://www.gnu.org/licenses/.
 # ==============================================================================
 import json
-from argparse import ArgumentParser
-from tfaip.base.imports import Trainer
 import logging
 import os
+from argparse import ArgumentParser
+
+from tensorflow import keras
+
+from tfaip.imports import Trainer, WarmStartParams, WarmStarter
 
 logger = logging.getLogger(__name__)
 logging.basicConfig(level=logging.DEBUG)
@@ -28,32 +31,41 @@ logging.basicConfig(level=logging.DEBUG)
 def main():
     parser = ArgumentParser()
 
-    parser.add_argument('checkpoint_dir', type=str, help='path to the checkpoint dir to resume from')
+    parser.add_argument('output_dir', type=str, help='path to the checkpoint dir to resume from')
 
     args = parser.parse_args()
 
-    with open(os.path.join(args.checkpoint_dir, 'trainer_params.json')) as f:
+    with open(os.path.join(args.output_dir, 'trainer_params.json')) as f:
         d = json.load(f)
-        d['device_params']['gpus'] = []
+        d.get('device', {})['gpus'] = []
 
     trainer = Trainer.restore_trainer(d)
     scenario = trainer.scenario
-    params = trainer.params
-    scenario.setup_training('adam', params.skip_model_load_test,
-                            run_eagerly=params.force_eager,
-                            no_train_scope=params.no_train_scope)
+    data = scenario.create_data()
+    model = scenario.create_model()
+
+    inputs = data.create_input_layers()
+    outputs = model.build(inputs)
+    keras_model = keras.models.Model(inputs=inputs, outputs=outputs)
+    scenario._keras_predict_model = keras_model
+    scenario._export_graphs = model.export_graphs(inputs, outputs, data.create_target_as_input_layers())
 
     def store(path):
         print(f"Converting {path}")
         if os.path.exists(path):
-            scenario.keras_predict_model.load_weights(os.path.join(path, 'serve', 'variables', 'variables'))
+            warmstart_params = WarmStartParams(
+                model=os.path.join(path, 'serve'),
+                rename_targets=[f"BLSTM_{i}->BLSTM{i + 1}" for i in range(3)],
+            )
+            warmstarter = WarmStarter(warmstart_params)
+            warmstarter.warmstart(scenario.keras_predict_model)
             scenario.export(path, export_resources=False)
             print(f"{path} successfully written.")
         else:
             print(f"{path} not found. Skipping")
 
     for p in ['best', 'export']:
-        store(os.path.join(args.checkpoint_dir, p))
+        store(os.path.join(args.output_dir, p))
 
 
 if __name__ == '__main__':
